@@ -1,4 +1,4 @@
-from typing import List, Optional, Union, Any, Literal
+from typing import List, Optional, Union, Literal, Dict
 from pydantic import BaseModel
 
 class SystemMessage(BaseModel):
@@ -12,8 +12,8 @@ class UserMessage(BaseModel):
 class AssistantMessage(BaseModel):
     role: Literal['assistant']
     content: str
-    agenticSender: Optional[str] = None
-    agenticResponseType: Literal['internal', 'external']
+    agenticName: Optional[str] = None
+    responseType: Literal['internal', 'external']
 
 class FunctionCall(BaseModel):
     name: str
@@ -27,15 +27,14 @@ class ToolCall(BaseModel):
 class AssistantMessageWithToolCalls(BaseModel):
     role: Literal['assistant']
     content: Optional[str] = None
-    tool_calls: List[ToolCall]
-    agenticSender: Optional[str] = None
-    agenticResponseType: Literal['internal', 'external']
+    toolCalls: List[ToolCall]
+    agenticName: Optional[str] = None
 
 class ToolMessage(BaseModel):
     role: Literal['tool']
     content: str
-    tool_call_id: str
-    tool_name: str
+    toolCallId: str
+    toolName: str
 
 ApiMessage = Union[
     SystemMessage,
@@ -45,10 +44,15 @@ ApiMessage = Union[
     ToolMessage
 ]
 
+class Turn(BaseModel):
+    id: str
+    output: List[ApiMessage]
+
 class ApiRequest(BaseModel):
+    conversationId: Optional[str] = None
     messages: List[ApiMessage]
-    state: Any
+    mockTools: Optional[Dict[str, str]] = None
 
 class ApiResponse(BaseModel):
-    messages: List[ApiMessage]
-    state: Any 
\ No newline at end of file
+    conversationId: str
+    turn: Turn
\ No newline at end of file
